@@ -82,7 +82,8 @@ C<--test_files> argument.
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
-L<http://rt.cpan.org>, or in electronic mail to the author.
+L<https://github.com/trwyant/perl-Mac-Pasteboard/issues>, or in
+electronic mail to the author.
 
 =head1 AUTHOR
 
@@ -90,7 +91,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009, 2011-2019 by Thomas R. Wyant, III
+Copyright (C) 2009, 2011-2021 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
