@@ -8,13 +8,14 @@ use warnings;
 use Carp;
 use Test::More 0.88;
 
-use base qw{ Exporter };
+use Exporter;
+our @ISA = qw{ Exporter };
 
 no if "$]" >= 5.020, feature => qw{ signatures };
 
 use constant CAN_USE_UNICODE	=> "$]" >= 5.008004;
 
-our $VERSION = '0.012_01';
+our $VERSION = '0.012_02';
 
 our @EXPORT =		## no critic (ProhibitAutomaticExportation)
 qw{
