@@ -6,6 +6,9 @@ use strict;
 use warnings;
 
 use Carp;
+use Exporter;
+
+our @ISA = qw{ Exporter };
 
 use constant CAN_USE_UNICODE	=> "$]" >= 5.008004;
 
@@ -21,8 +24,6 @@ BEGIN {
     $ENV{DEVELOPER_DEBUG} and Carp->import ('verbose');
 }
 
-use base qw{ Exporter };
-
 use constant CODE_REF	=> ref sub {};
 
 {
@@ -60,7 +61,7 @@ use constant CODE_REF	=> ref sub {};
     our @EXPORT = @funcs;	## no critic (ProhibitAutomaticExportation)
 }
 
-our $VERSION = '0.012_01';
+our $VERSION = '0.012_02';
 our $XS_VERSION = $VERSION;
 our $ALPHA_VERSION = $VERSION;
 $VERSION =~ s/_//g;
